<?php
namespace KERN23\ContentDesigner\Hooks;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2013 Hendrik Reimers <kontakt@kern23.de>
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 * Class/Function which manipulates the rendering of items within the new content element wizard
 *
 * @author		Hendrik Reimers <kontakt@kern23.de>
 * @package		TYPO3
 * @subpackage	tx_contentdesigner
 */
class WizardItems implements \TYPO3\CMS\Backend\Wizard\NewContentElementWizardHookInterface {
	
	/**
	 * @var string $prefixId
	 */
	private $prefixId = 'tx_contentdesigner';
	
	/**
	 * Processes the items of the new content element wizard
	 * and inserts necessary default values for items created within a grid
	 *
	 * @param	array				$wizardItems: The array containing the current status of the wizard item list before rendering
	 * @param	\db_new_content_el	$parentObject: The parent object that triggered this hook
	 * @return void
	 */
	public function manipulateWizardItems(&$wizardItems, &$parentObject) {
		$this->elements = \KERN23\ContentDesigner\Utility\TypoScript::loadConfig($config, $this->prefixId);
		$this->addContentDesignerItemsToWizard($this->elements,$wizardItems);
	}
	
	/**
	 * add cd Items to wizard items
	 *
	 * @param array $cdItems
	 * @param array $wizardItems
	 * @return void
	 */
	public function addContentDesignerItemsToWizard(&$cdItems, &$wizardItems) {
		// we have grid elements to add
		if(count($cdItems)) {
			// create gridelements node
			$wizardItems['cd'] = array();
			
			// set header label
			$_extConfig = unserialize($GLOBALS['TYPO3_CONF_VARS']['EXT']['extConf']['content_designer']);
			if ( trim($_extConfig['sheetTitle']) == '' ) $_extConfig['sheetTitle'] = 'LLL:EXT:content_designer/Resources/Private/Language/locallang_be.xml:wizard.sheetTitle';
			$wizardItems['cd']['header'] = ( preg_match("/^LLL:.*/i",$_extConfig['sheetTitle']) ) ? $GLOBALS['LANG']->sL($_extConfig['sheetTitle']) : trim($_extConfig['sheetTitle']);
			
			// traverse the gridelements and create wizard item for each gridelement
			foreach($cdItems as $cdObjKey => $CTypeData) {
				$cdObjKey = substr($cdObjKey,0,strlen($cdObjKey)-1);
				$CTypeData = $CTypeData['settings.'];
				
				$wizardItems['cd_'.$cdObjKey] = array(
					'icon'        => (( strlen($CTypeData['icon']) > 0 ) ? $CTypeData['icon'] : \TYPO3\CMS\Core\Utility\ExtensionManagementUtility::extRelPath('content_designer').'ce_wiz.gif'),
					'title'       => \KERN23\ContentDesigner\Utility\Helper::translate($CTypeData['title']),
					'description' => \KERN23\ContentDesigner\Utility\Helper::translate($CTypeData['description']),
					'params'      => '&defVals[tt_content][CType]='.$cdObjKey
				);
			}
		}
	}
}

?>